import { ZodSchema } from 'zod';
import {} from '../Interface/ToolInterface.js';
import { ZodSchemaValidatedAction } from '../Action/ZodSchemaValidatedAction.js';
import {} from '../Interface/ActionInterface.js';
/**
 * ActionTool is a specialized class that will use a given action as a tool.
 */
export class ActionTool extends ZodSchemaValidatedAction {
    name;
    description;
    parameters;
    /**
     * Constructor.
     *
     * @param {string} name - The name of the tool
     * @param {string} description - The description of the tool
     * @param {TypePayloadSchema} payloadSchema - The Zod schema for the input data
     * @param {TypeResponseSchema} responseSchema - The Zod schema for the output data
     * @param {ActionInterface<Infer<TypePayloadSchema>, Infer<TypeResponseSchema>>} action - The action to wrap
     */
    constructor(name, description, payloadSchema, responseSchema, action) {
        super(payloadSchema, responseSchema, action);
        this.name = name;
        this.description = description;
        this.parameters = payloadSchema;
    }
}
